.. -*- mode: rst ; ispell-local-dictionary: "american" -*-


git flow |BRANCH| list - List |BRANCH| branches
======================================================


Synopsis
-----------

.. parsed-literal::

  `git flow` |`BRANCH`| `list` [-v|--verbose]


Description
-----------

List all existing |BRANCH| branches in the local repository.


Options
-----------

  -h, --help     Show help message and exit.
  -v, --verbose  Be verbose (more output).
